==> kubernetes-model-policy-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/policy/v1/PodDisruptionBudgetSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PodDisruptionBudgetSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent<A>{
  public PodDisruptionBudgetSpecFluentImpl() {
  }
  public PodDisruptionBudgetSpecFluentImpl(io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpec instance) {
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
    this.withMinAvailable(instance.getMinAvailable()); 
    this.withSelector(instance.getSelector()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.IntOrStringBuilder maxUnavailable;
  private io.fabric8.kubernetes.api.model.IntOrStringBuilder minAvailable;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder selector;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getMaxUnavailable() {
    return this.maxUnavailable!=null?this.maxUnavailable.build():null;
  }
  public io.fabric8.kubernetes.api.model.IntOrString buildMaxUnavailable() {
    return this.maxUnavailable!=null?this.maxUnavailable.build():null;
  }
  public A withMaxUnavailable(io.fabric8.kubernetes.api.model.IntOrString maxUnavailable) {
    _visitables.get("maxUnavailable").remove(this.maxUnavailable);
    if (maxUnavailable!=null){ this.maxUnavailable= new io.fabric8.kubernetes.api.model.IntOrStringBuilder(maxUnavailable); _visitables.get("maxUnavailable").add(this.maxUnavailable);} return (A) this;
  }
  public java.lang.Boolean hasMaxUnavailable() {
    return this.maxUnavailable != null;
  }
  public A withNewMaxUnavailable(java.lang.Integer intVal) {
    return (A)withMaxUnavailable(new IntOrString(intVal));
  }
  public A withNewMaxUnavailable(java.lang.String strVal) {
    return (A)withMaxUnavailable(new IntOrString(strVal));
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> withNewMaxUnavailable() {
    return new io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluentImpl.MaxUnavailableNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return new io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluentImpl.MaxUnavailableNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable());
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): new io.fabric8.kubernetes.api.model.IntOrStringBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMinAvailable instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getMinAvailable() {
    return this.minAvailable!=null?this.minAvailable.build():null;
  }
  public io.fabric8.kubernetes.api.model.IntOrString buildMinAvailable() {
    return this.minAvailable!=null?this.minAvailable.build():null;
  }
  public A withMinAvailable(io.fabric8.kubernetes.api.model.IntOrString minAvailable) {
    _visitables.get("minAvailable").remove(this.minAvailable);
    if (minAvailable!=null){ this.minAvailable= new io.fabric8.kubernetes.api.model.IntOrStringBuilder(minAvailable); _visitables.get("minAvailable").add(this.minAvailable);} return (A) this;
  }
  public java.lang.Boolean hasMinAvailable() {
    return this.minAvailable != null;
  }
  public A withNewMinAvailable(java.lang.Integer intVal) {
    return (A)withMinAvailable(new IntOrString(intVal));
  }
  public A withNewMinAvailable(java.lang.String strVal) {
    return (A)withMinAvailable(new IntOrString(strVal));
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<A> withNewMinAvailable() {
    return new io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluentImpl.MinAvailableNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<A> withNewMinAvailableLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return new io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluentImpl.MinAvailableNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editMinAvailable() {
    return withNewMinAvailableLike(getMinAvailable());
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editOrNewMinAvailable() {
    return withNewMinAvailableLike(getMinAvailable() != null ? getMinAvailable(): new io.fabric8.kubernetes.api.model.IntOrStringBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editOrNewMinAvailableLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return withNewMinAvailableLike(getMinAvailable() != null ? getMinAvailable(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
  }
  public java.lang.Boolean hasSelector() {
    return this.selector != null;
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<A> withNewSelector() {
    return new io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluentImpl.SelectorNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluentImpl.SelectorNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<A> editSelector() {
    return withNewSelectorLike(getSelector());
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodDisruptionBudgetSpecFluentImpl that = (PodDisruptionBudgetSpecFluentImpl) o;
    if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
    if (minAvailable != null ? !minAvailable.equals(that.minAvailable) :that.minAvailable != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxUnavailable,  minAvailable,  selector,  additionalProperties,  super.hashCode());
  }
  public class MaxUnavailableNestedImpl<N> extends io.fabric8.kubernetes.api.model.IntOrStringFluentImpl<io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<N>> implements io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MaxUnavailableNestedImpl(io.fabric8.kubernetes.api.model.IntOrString item) {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this, item);
    }
    MaxUnavailableNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this);
    }
    io.fabric8.kubernetes.api.model.IntOrStringBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetSpecFluentImpl.this.withMaxUnavailable(builder.build());
    }
    public N endMaxUnavailable() {
      return and();
    }
    
  }
  public class MinAvailableNestedImpl<N> extends io.fabric8.kubernetes.api.model.IntOrStringFluentImpl<io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<N>> implements io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MinAvailableNestedImpl(io.fabric8.kubernetes.api.model.IntOrString item) {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this, item);
    }
    MinAvailableNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this);
    }
    io.fabric8.kubernetes.api.model.IntOrStringBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetSpecFluentImpl.this.withMinAvailable(builder.build());
    }
    public N endMinAvailable() {
      return and();
    }
    
  }
  public class SelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<N>> implements io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    SelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetSpecFluentImpl.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-policy-5.12.1-sources.jar: io/fabric8/kubernetes/api/model/policy/v1/PodDisruptionBudgetSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PodDisruptionBudgetSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent<A>{
  public PodDisruptionBudgetSpecFluentImpl() {
  }
  public PodDisruptionBudgetSpecFluentImpl(io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpec instance) {
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
    this.withMinAvailable(instance.getMinAvailable()); 
    this.withSelector(instance.getSelector()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.IntOrStringBuilder maxUnavailable;
  private io.fabric8.kubernetes.api.model.IntOrStringBuilder minAvailable;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder selector;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getMaxUnavailable() {
    return this.maxUnavailable!=null?this.maxUnavailable.build():null;
  }
  public io.fabric8.kubernetes.api.model.IntOrString buildMaxUnavailable() {
    return this.maxUnavailable!=null?this.maxUnavailable.build():null;
  }
  public A withMaxUnavailable(io.fabric8.kubernetes.api.model.IntOrString maxUnavailable) {
    _visitables.get("maxUnavailable").remove(this.maxUnavailable);
    if (maxUnavailable!=null){ this.maxUnavailable= new io.fabric8.kubernetes.api.model.IntOrStringBuilder(maxUnavailable); _visitables.get("maxUnavailable").add(this.maxUnavailable);} return (A) this;
  }
  public java.lang.Boolean hasMaxUnavailable() {
    return this.maxUnavailable != null;
  }
  public A withNewMaxUnavailable(java.lang.Integer intVal) {
    return (A)withMaxUnavailable(new IntOrString(intVal));
  }
  public A withNewMaxUnavailable(java.lang.String strVal) {
    return (A)withMaxUnavailable(new IntOrString(strVal));
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> withNewMaxUnavailable() {
    return new io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluentImpl.MaxUnavailableNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return new io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluentImpl.MaxUnavailableNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable());
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): new io.fabric8.kubernetes.api.model.IntOrStringBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMinAvailable instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getMinAvailable() {
    return this.minAvailable!=null?this.minAvailable.build():null;
  }
  public io.fabric8.kubernetes.api.model.IntOrString buildMinAvailable() {
    return this.minAvailable!=null?this.minAvailable.build():null;
  }
  public A withMinAvailable(io.fabric8.kubernetes.api.model.IntOrString minAvailable) {
    _visitables.get("minAvailable").remove(this.minAvailable);
    if (minAvailable!=null){ this.minAvailable= new io.fabric8.kubernetes.api.model.IntOrStringBuilder(minAvailable); _visitables.get("minAvailable").add(this.minAvailable);} return (A) this;
  }
  public java.lang.Boolean hasMinAvailable() {
    return this.minAvailable != null;
  }
  public A withNewMinAvailable(java.lang.Integer intVal) {
    return (A)withMinAvailable(new IntOrString(intVal));
  }
  public A withNewMinAvailable(java.lang.String strVal) {
    return (A)withMinAvailable(new IntOrString(strVal));
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<A> withNewMinAvailable() {
    return new io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluentImpl.MinAvailableNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<A> withNewMinAvailableLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return new io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluentImpl.MinAvailableNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editMinAvailable() {
    return withNewMinAvailableLike(getMinAvailable());
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editOrNewMinAvailable() {
    return withNewMinAvailableLike(getMinAvailable() != null ? getMinAvailable(): new io.fabric8.kubernetes.api.model.IntOrStringBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editOrNewMinAvailableLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return withNewMinAvailableLike(getMinAvailable() != null ? getMinAvailable(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
  }
  public java.lang.Boolean hasSelector() {
    return this.selector != null;
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<A> withNewSelector() {
    return new io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluentImpl.SelectorNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluentImpl.SelectorNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<A> editSelector() {
    return withNewSelectorLike(getSelector());
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodDisruptionBudgetSpecFluentImpl that = (PodDisruptionBudgetSpecFluentImpl) o;
    if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
    if (minAvailable != null ? !minAvailable.equals(that.minAvailable) :that.minAvailable != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxUnavailable,  minAvailable,  selector,  additionalProperties,  super.hashCode());
  }
  public class MaxUnavailableNestedImpl<N> extends io.fabric8.kubernetes.api.model.IntOrStringFluentImpl<io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<N>> implements io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MaxUnavailableNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MaxUnavailableNestedImpl(io.fabric8.kubernetes.api.model.IntOrString item) {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this, item);
    }
    MaxUnavailableNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this);
    }
    io.fabric8.kubernetes.api.model.IntOrStringBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetSpecFluentImpl.this.withMaxUnavailable(builder.build());
    }
    public N endMaxUnavailable() {
      return and();
    }
    
  }
  public class MinAvailableNestedImpl<N> extends io.fabric8.kubernetes.api.model.IntOrStringFluentImpl<io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<N>> implements io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.MinAvailableNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MinAvailableNestedImpl(io.fabric8.kubernetes.api.model.IntOrString item) {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this, item);
    }
    MinAvailableNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this);
    }
    io.fabric8.kubernetes.api.model.IntOrStringBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetSpecFluentImpl.this.withMinAvailable(builder.build());
    }
    public N endMinAvailable() {
      return and();
    }
    
  }
  public class SelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<N>> implements io.fabric8.kubernetes.api.model.policy.v1.PodDisruptionBudgetSpecFluent.SelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    SelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetSpecFluentImpl.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  
}
